<?php
/**
 * @file
 * Functions for validating and hashing National Registry Number.
 */

define('BEIDIDP_PREFIX', 'pUJ122deM0');
define('BEIDIDP_SUFFIX', 'gwct5ZopY7');

/**
 * Hash unique National Registry Number.
 *
 * Storing the NRN without permission of the Privacy Commission may violate 
 * Belgian law. Please consult a legal expert.
 *
 * @param string $plain
 *   NRN in plain text
 *
 * @return string
 *   Hashed NRN
 */
function beididp_hash($plain) {
  // Change these variables in settings.php
  $prefix = variable_get('beididp_hash_prefix', BEIDIDP_PREFIX);
  $suffix = variable_get('beididp_hash_suffix', BEIDIDP_SUFFIX);
  return sha1($prefix . $plain . $suffix);
}

/**
 * Hash the citizen's unique National Registry Number.
 *
 * @param string $claimed_id
 *   URL containing the (unhashed) NRN
 *
 * @return string
 *   URL containing the hashed NRN
 */
function beididp_hash_rrn($claimed_id) {
  $pattern = "/(.+\?)(\d{11})$/";

  if (preg_match($pattern, $claimed_id, $matches) > 0 && is_array($matches) && count($matches) == 3) {
    $hash = $matches[1] . beididp_hash($matches[2]);
  }
  else {
    $hash = beididp_hash($claimed_id);
  }

  return $hash;
}
